==> billogram-foundation-4.6.0.tgz: package/modules/components/datepicker/Datepicker.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Datepicker from './Datepicker';
import datepickerState from './redux/datepickerState';


const TestDatepicker = Datepicker({
    block: purebem.of('test-datepicker'),
    displayName: 'TestDatepicker'
});

test('should render empty text if no options', () => {
    const datepicker = mount(
        <TestDatepicker
            emptyText="Empty" />
    );

    expect(datepicker.text()).toBe('Empty');
});

[
    { name: 'should render date if passed as Date', data: { value: +new Date(2000, 0, 1) } },
    { name: 'should render date if passed as timestamp', data: { value: 946681200000 } }
].forEach((fixture) => {
    test(fixture.name, () => {
        const datepicker = mount(
            <TestDatepicker
                { ...datepickerState({ value: fixture.data.value }) } />
        );

        expect(datepicker.text()).toBe('2000-01-01');
    });
});

test('should expand collapsed datepicker when clicked', () => {
    const onExpand = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ value: +new Date(2000, 0, 1) }) }
            onExpand={ onExpand } />
    );

    datepicker.find('TestDatepickerControl').simulate('click');

    expect(onExpand).toHaveBeenCalled();
});

[
    { name: 'should expand collapsed datepicker when using enter', data: { which: 13 } },
    { name: 'should expand collapsed datepicker when using space', data: { which: 32 } },
    { name: 'should expand collapsed datepicker when using down arrow', data: { which: 40 } }
].forEach((fixture) => {
    test(fixture.name, () => {
        const onExpand = jest.fn();
        const dropdown = mount(
            <TestDatepicker
                { ...datepickerState({ value: +new Date(2000, 0, 1) }) }
                onExpand={ onExpand } />
        );

        dropdown.simulate('keydown', { which: fixture.data.which });

        expect(onExpand).toHaveBeenCalled();
    });
});

test('should not expand collapsed datepicked when click and disabled', () => {
    const onExpand = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ value: +new Date(2000, 0, 1) }) }
            disabled={ true }
            onExpand={ onExpand } />
    );

    datepicker.find('TestDatepickerControl').simulate('click');

    expect(onExpand).not.toHaveBeenCalled();
});

test('should collapse expanded dropdown when clicked', () => {
    const onCollapse = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 1) }) }
            onCollapse={ onCollapse } />
    );

    datepicker.find('TestDatepickerControl').simulate('click');

    expect(onCollapse).toHaveBeenCalled();
});

test('should collapse expanded dropdown when clicking outside', () => {
    const onCollapse = jest.fn();

    mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 1) }) }
            onCollapse={ onCollapse } />
    );

    document.dispatchEvent(new Event('mousedown'));
    expect(onCollapse).toHaveBeenCalled();
});

test('should collapse expanded dropdown when using escape', () => {
    const onCollapse = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 1) }) }
            onCollapse={ onCollapse } />
    );

    datepicker.simulate('keydown', { which: 27 });

    expect(onCollapse).toHaveBeenCalled();
});

[
    { name: 'should go to previous date when using left arrow when expanded', data: { which: 37 }, expected: { highlightedIndex: +new Date(2000, 0, 18) } },
    { name: 'should go to previous week when using up arrow when expanded', data: { which: 38 }, expected: { highlightedIndex: +new Date(2000, 0, 12) } },
    { name: 'should go to next date when using right arrow when expanded', data: { which: 39 }, expected: { highlightedIndex: +new Date(2000, 0, 20) } },
    { name: 'should go to next week when using down arrow when expanded', data: { which: 40 }, expected: { highlightedIndex: +new Date(2000, 0, 26) } }
].forEach((fixture) => {
    test(fixture.name, () => {
        const onHighlightedIndexChange = jest.fn();
        const datepicker = mount(
            <TestDatepicker
                { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 19) }) }
                onHighlightedIndexChange={ onHighlightedIndexChange } />
        );

        datepicker.simulate('keydown', { which: fixture.data.which });

        expect(onHighlightedIndexChange).toHaveBeenCalledWith(+new Date(2000, 0, 1), fixture.expected.highlightedIndex);
    });
});

[
    { name: 'should go to previous date/month when using left arrow when expanded', data: { which: 37 }, expected: { currentMonth: +new Date(2000, 0, 1), highlightedIndex: +new Date(2000, 0, 29) } },
    { name: 'should go to previous week/month when using up arrow when expanded', data: { which: 38 }, expected: { currentMonth: +new Date(2000, 0, 1), highlightedIndex: +new Date(2000, 0, 23) } }
].forEach((fixture) => {
    test(fixture.name, () => {
        const onHighlightedIndexChange = jest.fn();
        const datepicker = mount(
            <TestDatepicker
                { ...datepickerState({ expanded: true, value: +new Date(2000, 1, 1) }) }
                onHighlightedIndexChange={ onHighlightedIndexChange }
                highlightedIndex={ +new Date(2000, 0, 30) } />
        );

        datepicker.find('TestDatepickerControl').simulate('click');
        datepicker.simulate('keydown', { which: fixture.data.which });

        expect(onHighlightedIndexChange).toHaveBeenCalledWith(fixture.expected.currentMonth, fixture.expected.highlightedIndex);
    });
});

[
    { name: 'should go to next date/month when using right arrow when expanded', data: { which: 39 }, expected: { currentMonth: +new Date(2000, 1, 1), highlightedIndex: +new Date(2000, 1, 6) } },
    { name: 'should go to next week/month when using down arrow when expanded', data: { which: 40 }, expected: { currentMonth: +new Date(2000, 1, 1), highlightedIndex: +new Date(2000, 1, 12) } }
].forEach((fixture) => {
    test(fixture.name, () => {
        const onHighlightedIndexChange = jest.fn();
        const datepicker = mount(
            <TestDatepicker
                { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 31) }) }
                onHighlightedIndexChange={ onHighlightedIndexChange }
                highlightedIndex={ +new Date(2000, 1, 5) } />
        );

        datepicker.find('TestDatepickerControl').simulate('click');
        datepicker.simulate('keydown', { which: fixture.data.which });

        expect(onHighlightedIndexChange).toHaveBeenCalledWith(fixture.expected.currentMonth, fixture.expected.highlightedIndex);
    });
});

test('should go to next month when using tab key when expanded', () => {
    const onHighlightedIndexChange = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 19) }) }
            onHighlightedIndexChange={ onHighlightedIndexChange } />
    );

    datepicker.simulate('keydown', { which: 9 });

    expect(onHighlightedIndexChange).toHaveBeenCalledWith(+new Date(2000, 1, 1), +new Date(2000, 1, 19));
});

test('should go to previous month when using shift + tab key when expanded', () => {
    const onHighlightedIndexChange = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 19) }) }
            onHighlightedIndexChange={ onHighlightedIndexChange } />
    );

    datepicker.simulate('keydown', { shiftKey: true, which: 9 });

    expect(onHighlightedIndexChange).toHaveBeenCalledWith(+new Date(1999, 11, 1), +new Date(1999, 11, 19));
});

==> billogram-foundation-4.8.1.tgz: package/modules/components/datepicker/Datepicker.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Datepicker from './Datepicker';
import datepickerState from './redux/datepickerState';


const TestDatepicker = Datepicker({
    block: purebem.of('test-datepicker'),
    displayName: 'TestDatepicker',
});

test('should render empty text if no options', () => {
    const datepicker = mount(
        <TestDatepicker
            emptyText="Empty" />
    );

    expect(datepicker.text()).toBe('Empty');
});

[
    { name: 'should render date if passed as Date', data: { value: +new Date(2000, 0, 1) } },
    { name: 'should render date if passed as timestamp', data: { value: 946681200000 } },
].forEach((fixture) => {
    test(fixture.name, () => {
        const datepicker = mount(
            <TestDatepicker
                { ...datepickerState({ value: fixture.data.value }) } />
        );

        expect(datepicker.text()).toBe('2000-01-01');
    });
});

test('should expand collapsed datepicker when clicked', () => {
    const onExpand = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ value: +new Date(2000, 0, 1) }) }
            onExpand={ onExpand } />
    );

    datepicker.find('TestDatepickerControl').simulate('click');

    expect(onExpand).toHaveBeenCalled();
});

[
    { name: 'should expand collapsed datepicker when using enter', data: { which: 13 } },
    { name: 'should expand collapsed datepicker when using space', data: { which: 32 } },
    { name: 'should expand collapsed datepicker when using down arrow', data: { which: 40 } },
].forEach((fixture) => {
    test(fixture.name, () => {
        const onExpand = jest.fn();
        const dropdown = mount(
            <TestDatepicker
                { ...datepickerState({ value: +new Date(2000, 0, 1) }) }
                onExpand={ onExpand } />
        );

        dropdown.simulate('keydown', { which: fixture.data.which });

        expect(onExpand).toHaveBeenCalled();
    });
});

test('should not expand collapsed datepicked when click and disabled', () => {
    const onExpand = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ value: +new Date(2000, 0, 1) }) }
            disabled={ true }
            onExpand={ onExpand } />
    );

    datepicker.find('TestDatepickerControl').simulate('click');

    expect(onExpand).not.toHaveBeenCalled();
});

test('should collapse expanded dropdown when clicked', () => {
    const onCollapse = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 1) }) }
            onCollapse={ onCollapse } />
    );

    datepicker.find('TestDatepickerControl').simulate('click');

    expect(onCollapse).toHaveBeenCalled();
});

test('should collapse expanded dropdown when clicking outside', () => {
    const onCollapse = jest.fn();

    mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 1) }) }
            onCollapse={ onCollapse } />
    );

    document.dispatchEvent(new Event('mousedown'));
    expect(onCollapse).toHaveBeenCalled();
});

test('should collapse expanded dropdown when using escape', () => {
    const onCollapse = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 1) }) }
            onCollapse={ onCollapse } />
    );

    datepicker.simulate('keydown', { which: 27 });

    expect(onCollapse).toHaveBeenCalled();
});

[
    { name: 'should go to previous date when using left arrow when expanded', data: { which: 37 }, expected: { highlightedIndex: +new Date(2000, 0, 18) } },
    { name: 'should go to previous week when using up arrow when expanded', data: { which: 38 }, expected: { highlightedIndex: +new Date(2000, 0, 12) } },
    { name: 'should go to next date when using right arrow when expanded', data: { which: 39 }, expected: { highlightedIndex: +new Date(2000, 0, 20) } },
    { name: 'should go to next week when using down arrow when expanded', data: { which: 40 }, expected: { highlightedIndex: +new Date(2000, 0, 26) } },
].forEach((fixture) => {
    test(fixture.name, () => {
        const onHighlightedIndexChange = jest.fn();
        const datepicker = mount(
            <TestDatepicker
                { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 19) }) }
                onHighlightedIndexChange={ onHighlightedIndexChange } />
        );

        datepicker.simulate('keydown', { which: fixture.data.which });

        expect(onHighlightedIndexChange).toHaveBeenCalledWith(+new Date(2000, 0, 1), fixture.expected.highlightedIndex);
    });
});

[
    { name: 'should go to previous date/month when using left arrow when expanded', data: { which: 37 }, expected: { currentMonth: +new Date(2000, 0, 1), highlightedIndex: +new Date(2000, 0, 29) } },
    { name: 'should go to previous week/month when using up arrow when expanded', data: { which: 38 }, expected: { currentMonth: +new Date(2000, 0, 1), highlightedIndex: +new Date(2000, 0, 23) } },
].forEach((fixture) => {
    test(fixture.name, () => {
        const onHighlightedIndexChange = jest.fn();
        const datepicker = mount(
            <TestDatepicker
                { ...datepickerState({ expanded: true, value: +new Date(2000, 1, 1) }) }
                onHighlightedIndexChange={ onHighlightedIndexChange }
                highlightedIndex={ +new Date(2000, 0, 30) } />
        );

        datepicker.find('TestDatepickerControl').simulate('click');
        datepicker.simulate('keydown', { which: fixture.data.which });

        expect(onHighlightedIndexChange).toHaveBeenCalledWith(fixture.expected.currentMonth, fixture.expected.highlightedIndex);
    });
});

[
    { name: 'should go to next date/month when using right arrow when expanded', data: { which: 39 }, expected: { currentMonth: +new Date(2000, 1, 1), highlightedIndex: +new Date(2000, 1, 6) } },
    { name: 'should go to next week/month when using down arrow when expanded', data: { which: 40 }, expected: { currentMonth: +new Date(2000, 1, 1), highlightedIndex: +new Date(2000, 1, 12) } },
].forEach((fixture) => {
    test(fixture.name, () => {
        const onHighlightedIndexChange = jest.fn();
        const datepicker = mount(
            <TestDatepicker
                { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 31) }) }
                onHighlightedIndexChange={ onHighlightedIndexChange }
                highlightedIndex={ +new Date(2000, 1, 5) } />
        );

        datepicker.find('TestDatepickerControl').simulate('click');
        datepicker.simulate('keydown', { which: fixture.data.which });

        expect(onHighlightedIndexChange).toHaveBeenCalledWith(fixture.expected.currentMonth, fixture.expected.highlightedIndex);
    });
});

test('should go to next month when using tab key when expanded', () => {
    const onHighlightedIndexChange = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 19) }) }
            onHighlightedIndexChange={ onHighlightedIndexChange } />
    );

    datepicker.simulate('keydown', { which: 9 });

    expect(onHighlightedIndexChange).toHaveBeenCalledWith(+new Date(2000, 1, 1), +new Date(2000, 1, 19));
});

test('should go to previous month when using shift + tab key when expanded', () => {
    const onHighlightedIndexChange = jest.fn();
    const datepicker = mount(
        <TestDatepicker
            { ...datepickerState({ expanded: true, value: +new Date(2000, 0, 19) }) }
            onHighlightedIndexChange={ onHighlightedIndexChange } />
    );

    datepicker.simulate('keydown', { shiftKey: true, which: 9 });

    expect(onHighlightedIndexChange).toHaveBeenCalledWith(+new Date(1999, 11, 1), +new Date(1999, 11, 19));
});
